@@ -91,7 +91,7 @@ class api:
     def setStaticDir(self, dir_):
         self.staticDir = dir_
 
-    def run(self, app):
+    def run(self, app, host):
         print("run")
 
         if (self.name).endswith(".py"):
@@ -100,7 +100,7 @@ class api:
         else:
             self.fname = self.name + ".py"
         
-        sys.argv = [re.sub(r'(-script\.pyw|\.exe)?$', '', "env/bin/gunicorn"),self.name+':'+ app, "-b", self.hostAddr]
+        sys.argv = [re.sub(r'(-script\.pyw|\.exe)?$', '', "env/bin/gunicorn"),self.name+':'+ app, "-b", host]
         print(sys.argv)
         sys.exit(boot())
         
